package com.jjt.inventory.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.jjt.common.utils.DateUtils;
import com.jjt.inventory.domain.TwinCalcHourPt;
import com.jjt.inventory.mapper.TwinCalcHourPtMapper;
import com.jjt.inventory.service.ITwinCalcHourPtService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.LocalDate;
import java.util.Date;
import java.util.List;

/**
 * 盘头仓库小时数据Service业务层处理
 *
 * @author wukai
 * @date 2025-06-10
 */
@Service
public class TwinCalcHourPtServiceImpl implements ITwinCalcHourPtService {
    @Resource
    private TwinCalcHourPtMapper twinCalcHourPtMapper;

    /**
     * 查询盘头仓库小时数据
     *
     * @param id 盘头仓库小时数据主键
     * @return 盘头仓库小时数据
     */
    @Override
    public TwinCalcHourPt selectTwinCalcHourPtById(Long id) {
        return twinCalcHourPtMapper.selectTwinCalcHourPtById(id);
    }

    /**
     * 查询盘头仓库小时数据列表
     *
     * @param twinCalcHourPt 盘头仓库小时数据
     * @return 盘头仓库小时数据
     */
    @Override
    public List<TwinCalcHourPt> selectTwinCalcHourPtList(TwinCalcHourPt twinCalcHourPt) {
        return twinCalcHourPtMapper.selectTwinCalcHourPtList(twinCalcHourPt);
    }

    /**
     * 新增盘头仓库小时数据
     *
     * @param twinCalcHourPt 盘头仓库小时数据
     * @return 结果
     */
    @Override
    public int insertTwinCalcHourPt(TwinCalcHourPt twinCalcHourPt) {
        return twinCalcHourPtMapper.insertTwinCalcHourPt(twinCalcHourPt);
    }

    /**
     * 修改盘头仓库小时数据
     *
     * @param twinCalcHourPt 盘头仓库小时数据
     * @return 结果
     */
    @Override
    public int updateTwinCalcHourPt(TwinCalcHourPt twinCalcHourPt) {
        return twinCalcHourPtMapper.updateTwinCalcHourPt(twinCalcHourPt);
    }

    /**
     * 批量删除盘头仓库小时数据
     *
     * @param ids 需要删除的盘头仓库小时数据主键
     * @return 结果
     */
    @Override
    public int deleteTwinCalcHourPtByIds(Long[] ids) {
        return twinCalcHourPtMapper.deleteTwinCalcHourPtByIds(ids);
    }

    /**
     * 删除盘头仓库小时数据信息
     *
     * @param id 盘头仓库小时数据主键
     * @return 结果
     */
    @Override
    public int deleteTwinCalcHourPtById(Long id) {
        return twinCalcHourPtMapper.deleteTwinCalcHourPtById(id);
    }

    /**
     * 按时间删除
     *
     * @param date 日期
     * @param hour 小时
     */
    @Override
    public void delete(LocalDate date, int hour) {
        QueryWrapper<TwinCalcHourPt> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("data_date", date);
        queryWrapper.eq("hour", hour);
        twinCalcHourPtMapper.delete(queryWrapper);
    }

    /**
     * 按时间查询
     *
     * @param date 日期
     * @return 结果
     */
    @Override
    public List<TwinCalcHourPt> selectTwinCalcHourPtByDay(LocalDate date) {
        TwinCalcHourPt query = new TwinCalcHourPt();
        query.setDataDate(DateUtils.toDate(date));
        return selectTwinCalcHourPtList(query);
    }

    /**
     * 按时间查询
     *
     * @param time 时间
     * @param hour 小时
     * @return 结果
     */
    @Override
    public List<TwinCalcHourPt> selectTwinCalcHourPtByHour(Date time, Integer hour) {
        TwinCalcHourPt query = new TwinCalcHourPt();
        query.setDataDate(time);
        query.setHour(hour);
        return selectTwinCalcHourPtList(query);
    }
}
